@@ -160,7 +160,7 @@ expose_start_finder() {
 		py::scope start_finder_scope = start_finder_class;
 		myrrh::python::def_function<
 			void(
-			    w_mer_evaluation::vec_ptr,
+			    start_finder_t::eval_vec_ptr,
 				const std::string &,
 				int,
 				double
